@@ -46,7 +46,6 @@ import static org.drools.workbench.screens.scenariosimulation.client.TestPropert
 import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.COLUMN_INDEX;
 import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.FACT_IDENTIFIER_NAME;
 import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.FACT_NAME;
-import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.FULL_CLASSNAME_CREATED;
 import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.FULL_CLASS_NAME;
 import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.FULL_PACKAGE;
 import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.FULL_PROPERTY_NAME_ELEMENTS;
@@ -60,12 +59,12 @@ import static org.drools.workbench.screens.scenariosimulation.client.TestPropert
 import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.PROPERTY_NAME;
 import static org.drools.workbench.screens.scenariosimulation.client.TestProperties.VALUE_CLASS_NAME;
 import static org.junit.Assert.assertEquals;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.anyBoolean;
-import static org.mockito.Matchers.anyInt;
-import static org.mockito.Matchers.anyString;
-import static org.mockito.Matchers.eq;
-import static org.mockito.Matchers.isA;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.anyBoolean;
+import static org.mockito.ArgumentMatchers.anyInt;
+import static org.mockito.ArgumentMatchers.anyString;
+import static org.mockito.ArgumentMatchers.eq;
+import static org.mockito.ArgumentMatchers.isA;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
@@ -85,7 +84,6 @@ public abstract class AbstractSelectedColumnCommandTest extends AbstractScenario
         super.setup();
 
         when(gridColumnsMock.indexOf(gridColumnMock)).thenReturn(COLUMN_INDEX);
-        settingsLocal.setType(ScenarioSimulationModel.Type.RULE);
         when(factModelTreeMock.getExpandableProperties()).thenReturn(mock(SortedMap.class));
         when(dataObjectFieldsMapMock.get(anyString())).thenReturn(factModelTreeMock);
 
@@ -95,6 +93,7 @@ public abstract class AbstractSelectedColumnCommandTest extends AbstractScenario
         scenarioSimulationContextLocal.getStatus().setColumnId(COLUMN_ID);
         scenarioSimulationContextLocal.getStatus().setColumnIndex(COLUMN_INDEX);
         scenarioSimulationContextLocal.getStatus().setPropertyNameElements(MULTIPART_VALUE_ELEMENTS);
+        scenarioSimulationContextLocal.getStatus().setClassName(CLASS_NAME);
     }
 
     @Test
@@ -136,8 +135,8 @@ public abstract class AbstractSelectedColumnCommandTest extends AbstractScenario
                 anyString(),
                 eq(columnGroup),
                 eq(factMappingType),
-                eq(scenarioHeaderTextBoxSingletonDOMElementFactoryTest),
-                eq(scenarioCellTextAreaSingletonDOMElementFactoryTest),
+                eq(scenarioHeaderTextBoxSingletonDOMElementFactorySpy),
+                eq(scenarioCellTextAreaSingletonDOMElementFactorySpy),
                 eq(ScenarioSimulationEditorConstants.INSTANCE.defineValidType()));
         if (cloneInstance) {
             verify(createdColumn, times(1)).setFactIdentifier(eq(gridColumnMock.getFactIdentifier()));
@@ -159,7 +158,6 @@ public abstract class AbstractSelectedColumnCommandTest extends AbstractScenario
     @Test
     public void executeKeepDataFalseRule() {
         scenarioSimulationContextLocal.getStatus().setKeepData(false);
-        settingsLocal.setType(ScenarioSimulationModel.Type.RULE);
         commonSetPropertyHeader(ScenarioSimulationModel.Type.RULE, false, MULTIPART_VALUE_ELEMENTS, VALUE_CLASS_NAME);
     }
 
@@ -174,13 +172,13 @@ public abstract class AbstractSelectedColumnCommandTest extends AbstractScenario
         scenarioSimulationContextLocal.getStatus().setValueClassName(LIST_CLASS_NAME);
         scenarioSimulationContextLocal.getStatus().setValue(FULL_PROPERTY_PATH);
         doReturn(factIdentifierMock).when(((AbstractSelectedColumnCommand) commandSpy)).setEditableHeadersAndGetFactIdentifier(eq(scenarioSimulationContextLocal), eq(gridColumnMock), eq(CLASS_NAME), eq(FULL_CLASS_NAME));
-        ((AbstractSelectedColumnCommand) commandSpy).setPropertyHeader(scenarioSimulationContextLocal, gridColumnMock, FULL_PROPERTY_PATH_ELEMENTS, LIST_CLASS_NAME);
+        ((AbstractSelectedColumnCommand) commandSpy).setPropertyHeader(scenarioSimulationContextLocal, gridColumnMock, FULL_CLASS_NAME, FULL_PROPERTY_PATH_ELEMENTS, LIST_CLASS_NAME);
         verify(((AbstractSelectedColumnCommand) commandSpy), times(2)).setInstanceHeaderMetaData(eq(gridColumnMock), eq(CLASS_NAME), eq(factIdentifierMock));
         verify(propertyHeaderMetaDataMock, times(1)).setColumnGroup(anyString());
         verify(propertyHeaderMetaDataMock, times(1)).setTitle(eq(LIST_PROPERTY_NAME));
         verify(propertyHeaderMetaDataMock, times(1)).setReadOnly(eq(false));
-        verify(scenarioGridModelMock, times(1)).updateColumnProperty(anyInt(), eq(gridColumnMock), eq(FULL_PROPERTY_PATH_ELEMENTS), eq(LIST_CLASS_NAME), anyBoolean(), isA(FactMappingValueType.class));
-        verify((AbstractSelectedColumnCommand) commandSpy, times(1)).manageCollectionProperty(eq(scenarioSimulationContextLocal), eq(gridColumnMock), eq(FULL_CLASSNAME_CREATED), eq(0), eq(FULL_PROPERTY_PATH_ELEMENTS));
+        verify(scenarioGridModelMock, times(1)).updateColumnProperty(anyInt(), eq(gridColumnMock), eq(FULL_PROPERTY_PATH_ELEMENTS), eq(LIST_CLASS_NAME), anyBoolean(), isA(FactMappingValueType.class), eq(ScenarioSimulationModel.Type.RULE));
+        verify((AbstractSelectedColumnCommand) commandSpy, times(1)).manageCollectionProperty(eq(scenarioSimulationContextLocal), eq(gridColumnMock), eq(CLASS_NAME), eq(0), eq(FULL_PROPERTY_PATH_ELEMENTS));
         verify((AbstractSelectedColumnCommand) commandSpy, times(1)).navigateComplexObject(eq(factModelTreeMock), eq(FULL_PROPERTY_PATH_ELEMENTS), eq(scenarioSimulationContextLocal.getDataObjectFieldsMap()));
     }
 
@@ -190,13 +188,13 @@ public abstract class AbstractSelectedColumnCommandTest extends AbstractScenario
         scenarioSimulationContextLocal.getStatus().setValue(FULL_PROPERTY_PATH);
         when(gridColumnMock.isInstanceAssigned()).thenReturn(true);
         when(gridColumnMock.getInformationHeaderMetaData().getTitle()).thenReturn(CLASS_NAME);
-        ((AbstractSelectedColumnCommand) commandSpy).setPropertyHeader(scenarioSimulationContextLocal, gridColumnMock, FULL_PROPERTY_PATH_ELEMENTS, LIST_CLASS_NAME);
+        ((AbstractSelectedColumnCommand) commandSpy).setPropertyHeader(scenarioSimulationContextLocal, gridColumnMock, FULL_CLASS_NAME, FULL_PROPERTY_PATH_ELEMENTS, LIST_CLASS_NAME);
         verify(((AbstractSelectedColumnCommand) commandSpy), never()).setInstanceHeaderMetaData(eq(gridColumnMock), eq(CLASS_NAME), eq(factIdentifierMock));
         verify(propertyHeaderMetaDataMock, times(1)).setColumnGroup(anyString());
         verify(propertyHeaderMetaDataMock, times(1)).setTitle(eq(LIST_PROPERTY_NAME));
         verify(propertyHeaderMetaDataMock, times(1)).setReadOnly(eq(false));
-        verify(scenarioGridModelMock, times(1)).updateColumnProperty(anyInt(), eq(gridColumnMock), eq(FULL_PROPERTY_PATH_ELEMENTS), eq(LIST_CLASS_NAME), anyBoolean(), isA(FactMappingValueType.class));
-        verify((AbstractSelectedColumnCommand) commandSpy, times(1)).manageCollectionProperty(eq(scenarioSimulationContextLocal), eq(gridColumnMock), eq(FULL_CLASSNAME_CREATED), eq(0), eq(FULL_PROPERTY_PATH_ELEMENTS));
+        verify(scenarioGridModelMock, times(1)).updateColumnProperty(anyInt(), eq(gridColumnMock), eq(FULL_PROPERTY_PATH_ELEMENTS), eq(LIST_CLASS_NAME), anyBoolean(), isA(FactMappingValueType.class), eq(ScenarioSimulationModel.Type.RULE));
+        verify((AbstractSelectedColumnCommand) commandSpy, times(1)).manageCollectionProperty(eq(scenarioSimulationContextLocal), eq(gridColumnMock), eq(CLASS_NAME), eq(0), eq(FULL_PROPERTY_PATH_ELEMENTS));
         verify((AbstractSelectedColumnCommand) commandSpy, times(1)).navigateComplexObject(eq(factModelTreeMock), eq(FULL_PROPERTY_PATH_ELEMENTS), eq(scenarioSimulationContextLocal.getDataObjectFieldsMap()));
     }
 
@@ -206,13 +204,13 @@ public abstract class AbstractSelectedColumnCommandTest extends AbstractScenario
         scenarioSimulationContextLocal.getStatus().setValue(FULL_PROPERTY_PATH);
         when(gridColumnMock.isInstanceAssigned()).thenReturn(true);
         when(gridColumnMock.getInformationHeaderMetaData().getTitle()).thenReturn(CLASS_NAME);
-        ((AbstractSelectedColumnCommand) commandSpy).setPropertyHeader(scenarioSimulationContextLocal, gridColumnMock, FULL_PROPERTY_PATH_ELEMENTS, LIST_CLASS_NAME, PROPERTY_NAME);
+        ((AbstractSelectedColumnCommand) commandSpy).setPropertyHeader(scenarioSimulationContextLocal, gridColumnMock, FULL_CLASS_NAME, FULL_PROPERTY_PATH_ELEMENTS, LIST_CLASS_NAME, PROPERTY_NAME);
         verify(((AbstractSelectedColumnCommand) commandSpy), never()).setInstanceHeaderMetaData(eq(gridColumnMock), eq(CLASS_NAME), eq(factIdentifierMock));
         verify(propertyHeaderMetaDataMock, times(1)).setColumnGroup(anyString());
         verify(propertyHeaderMetaDataMock, times(1)).setTitle(eq(PROPERTY_NAME));
         verify(propertyHeaderMetaDataMock, times(1)).setReadOnly(eq(false));
-        verify(scenarioGridModelMock, times(1)).updateColumnProperty(anyInt(), eq(gridColumnMock), eq(FULL_PROPERTY_PATH_ELEMENTS), eq(LIST_CLASS_NAME), anyBoolean(), isA(FactMappingValueType.class));
-        verify((AbstractSelectedColumnCommand) commandSpy, times(1)).manageCollectionProperty(eq(scenarioSimulationContextLocal), eq(gridColumnMock), eq(FULL_CLASSNAME_CREATED), eq(0), eq(FULL_PROPERTY_PATH_ELEMENTS));
+        verify(scenarioGridModelMock, times(1)).updateColumnProperty(anyInt(), eq(gridColumnMock), eq(FULL_PROPERTY_PATH_ELEMENTS), eq(LIST_CLASS_NAME), anyBoolean(), isA(FactMappingValueType.class), eq(ScenarioSimulationModel.Type.RULE));
+        verify((AbstractSelectedColumnCommand) commandSpy, times(1)).manageCollectionProperty(eq(scenarioSimulationContextLocal), eq(gridColumnMock), eq(CLASS_NAME), eq(0), eq(FULL_PROPERTY_PATH_ELEMENTS));
         verify((AbstractSelectedColumnCommand) commandSpy, times(1)).navigateComplexObject(eq(factModelTreeMock), eq(FULL_PROPERTY_PATH_ELEMENTS), eq(scenarioSimulationContextLocal.getDataObjectFieldsMap()));
     }
 
@@ -221,13 +219,13 @@ public abstract class AbstractSelectedColumnCommandTest extends AbstractScenario
         scenarioSimulationContextLocal.getStatus().setValueClassName(LIST_CLASS_NAME);
         scenarioSimulationContextLocal.getStatus().setValue(FULL_PROPERTY_PATH);
         when(gridColumnMock.isInstanceAssigned()).thenReturn(true);
-        ((AbstractSelectedColumnCommand) commandSpy).setPropertyHeader(scenarioSimulationContextLocal, gridColumnMock, FULL_PROPERTY_PATH_ELEMENTS, LIST_CLASS_NAME);
+        ((AbstractSelectedColumnCommand) commandSpy).setPropertyHeader(scenarioSimulationContextLocal, gridColumnMock, FULL_CLASS_NAME, FULL_PROPERTY_PATH_ELEMENTS, LIST_CLASS_NAME);
         verify(((AbstractSelectedColumnCommand) commandSpy), never()).setInstanceHeaderMetaData(eq(gridColumnMock), eq(CLASS_NAME), eq(factIdentifierMock));
         verify(propertyHeaderMetaDataMock, never()).setColumnGroup(anyString());
         verify(propertyHeaderMetaDataMock, never()).setTitle(anyString());
         verify(propertyHeaderMetaDataMock, never()).setReadOnly(anyBoolean());
-        verify(scenarioGridModelMock, never()).updateColumnProperty(anyInt(), eq(gridColumnMock), eq(FULL_PROPERTY_PATH_ELEMENTS), eq(LIST_CLASS_NAME), anyBoolean(), isA(FactMappingValueType.class));
-        verify((AbstractSelectedColumnCommand) commandSpy, never()).manageCollectionProperty(eq(scenarioSimulationContextLocal), eq(gridColumnMock), eq(FULL_CLASSNAME_CREATED), eq(0), eq(FULL_PROPERTY_PATH_ELEMENTS));
+        verify(scenarioGridModelMock, never()).updateColumnProperty(anyInt(), eq(gridColumnMock), eq(FULL_PROPERTY_PATH_ELEMENTS), eq(LIST_CLASS_NAME), anyBoolean(), isA(FactMappingValueType.class), eq(ScenarioSimulationModel.Type.RULE));
+        verify((AbstractSelectedColumnCommand) commandSpy, never()).manageCollectionProperty(eq(scenarioSimulationContextLocal), eq(gridColumnMock), eq(CLASS_NAME), eq(0), eq(FULL_PROPERTY_PATH_ELEMENTS));
         verify((AbstractSelectedColumnCommand) commandSpy, never()).navigateComplexObject(eq(factModelTreeMock), eq(FULL_PROPERTY_PATH_ELEMENTS), eq(scenarioSimulationContextLocal.getDataObjectFieldsMap()));
     }
 
@@ -240,6 +238,19 @@ public abstract class AbstractSelectedColumnCommandTest extends AbstractScenario
         verify(informationHeaderMetaDataMock, times(1)).setTitle(eq(FACT_NAME));
     }
 
+    @Test
+    public void getFullPackage() {
+        scenarioSimulationContextLocal.getStatus().setFullPackage(FULL_PACKAGE);
+        String fullPackage = ((AbstractSelectedColumnCommand) commandSpy).getFullPackage(scenarioSimulationContextLocal);
+        assertEquals(fullPackage, FULL_PACKAGE + ".");
+        scenarioSimulationContextLocal.getStatus().setFullPackage("");
+        fullPackage = ((AbstractSelectedColumnCommand) commandSpy).getFullPackage(scenarioSimulationContextLocal);
+        assertEquals("", fullPackage);
+        scenarioSimulationContextLocal.getStatus().setFullPackage(null);
+        fullPackage = ((AbstractSelectedColumnCommand) commandSpy).getFullPackage(scenarioSimulationContextLocal);
+        assertEquals("", fullPackage);
+    }
+
     /* This test is usable ONLY by <code>SetPropertyCommandTest</code> subclass */
     public void manageCollectionProperty() {
         scenarioSimulationContextLocal.getStatus().setValueClassName(LIST_CLASS_NAME);
@@ -264,12 +275,12 @@ public abstract class AbstractSelectedColumnCommandTest extends AbstractScenario
     }
 
     protected void commonSetPropertyHeader(ScenarioSimulationModel.Type type, boolean keepData, List<String> propertyNameElements, String propertyClass) {
-        ((AbstractSelectedColumnCommand) commandSpy).setPropertyHeader(scenarioSimulationContextLocal, gridColumnMock, propertyNameElements, propertyClass);
+        ((AbstractSelectedColumnCommand) commandSpy).setPropertyHeader(scenarioSimulationContextLocal, gridColumnMock, FULL_CLASS_NAME, propertyNameElements, propertyClass);
         verify(gridColumnMock, times(1)).setEditableHeaders(eq(!type.equals(ScenarioSimulationModel.Type.DMN)));
         verify(propertyHeaderMetaDataMock, times(1)).setColumnGroup(anyString());
         verify(propertyHeaderMetaDataMock, times(1)).setTitle(String.join(".", propertyNameElements.subList(1, propertyNameElements.size())));
         verify(propertyHeaderMetaDataMock, times(1)).setReadOnly(false);
-        verify(scenarioGridModelMock, times(1)).updateColumnProperty(anyInt(), isA(ScenarioGridColumn.class), eq(propertyNameElements), eq(propertyClass), eq(keepData), isA(FactMappingValueType.class));
+        verify(scenarioGridModelMock, times(1)).updateColumnProperty(anyInt(), eq(gridColumnMock), eq(propertyNameElements), eq(propertyClass), eq(keepData), isA(FactMappingValueType.class), eq(type));
         verify(scenarioSimulationContextLocal.getScenarioSimulationEditorPresenter(), times(1)).reloadTestTools(false);
     }
 
@@ -287,6 +298,20 @@ public abstract class AbstractSelectedColumnCommandTest extends AbstractScenario
         verify(sortedMap, times(1)).get("Author");
     }
 
+    protected void navigateComplexObject3Levels() {
+        FactModelTree book = new FactModelTree("Book", "com.Book", new HashMap<>(), new HashMap<>());
+        book.addExpandableProperty("author", "Author");
+        FactModelTree author = new FactModelTree("Author", "com.Author", new HashMap<>(), new HashMap<>());
+        author.addExpandableProperty("firstBook", "Book");
+        SortedMap<String, FactModelTree> sortedMap = spy(new TreeMap<>());
+        sortedMap.put("Book", book);
+        sortedMap.put("Author", author);
+        List<String> elements = Arrays.asList("Book", "author", "firstBook", "topics");
+        FactModelTree target = ((AbstractSelectedColumnCommand) commandSpy).navigateComplexObject(book, elements, sortedMap);
+        assertEquals(target, book);
+        verify(sortedMap, times(1)).get("Author");
+    }
+
     /* This test is usable ONLY by <code>SetPropertyCommandTest</code> subclass */
     protected void getPropertyHeaderTitle() {
         Optional<String> emptyMatching = Optional.empty();
@@ -331,14 +356,15 @@ public abstract class AbstractSelectedColumnCommandTest extends AbstractScenario
         verify(simulationDescriptorMock, times(1)).getFactMappingsByFactName(eq(factIdentifierMock.getName()));
         assertEquals(Optional.empty(), retrieved);
         List<FactMapping> factMappingList = new ArrayList<>();
-        when(simulationDescriptorMock.getFactMappingsByFactName(FACT_IDENTIFIER_NAME)).thenReturn(factMappingList);
         factMappingList.add(factMappingMock);
+        when(simulationDescriptorMock.getFactMappingsByFactName(FACT_IDENTIFIER_NAME)).thenReturn(factMappingList.stream());
         String EXPRESSION_ALIAS = "EXPRESSION_ALIAS";
         when(factMappingMock.getExpressionAlias()).thenReturn(EXPRESSION_ALIAS);
         retrieved = ((AbstractSelectedColumnCommand) commandSpy).getMatchingExpressionAlias(scenarioSimulationContextLocal, FULL_PROPERTY_NAME_ELEMENTS, factIdentifierMock);
         assertEquals(Optional.empty(), retrieved);
         List<ExpressionElement> expressionElements = FULL_PROPERTY_NAME_ELEMENTS.stream().map(ExpressionElement::new).collect(Collectors.toList());
         when(factMappingMock.getExpressionElements()).thenReturn(expressionElements);
+        when(simulationDescriptorMock.getFactMappingsByFactName(FACT_IDENTIFIER_NAME)).thenReturn(factMappingList.stream());
         retrieved = ((AbstractSelectedColumnCommand) commandSpy).getMatchingExpressionAlias(scenarioSimulationContextLocal, FULL_PROPERTY_NAME_ELEMENTS, factIdentifierMock);
         assertEquals(Optional.of(EXPRESSION_ALIAS), retrieved);
     }
